##  Summary
In this tutorial, you learned how to:
  * Programmatically convert a CSV file into LDIF format using a Python script
  * Import links to application fact sheets using an inbound processor of the Integration API
